package org.clazzes.util.http;

import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;

public class FileResourceResolver implements HttpResourceResolver {
    
    private String dirName;
    private File directory;
    
    public void setDirName(String dirName) {
        this.dirName = dirName;
        this.directory = new File(this.dirName);
    }        
    
    public HttpResource resolveResource(String finalPath, int bufferSize) throws IOException {
        
        String relPath;
        
        if (finalPath.startsWith("/") || finalPath.startsWith("\\")) {
            relPath = finalPath.substring(1);
        }
        else {
            relPath = finalPath;
        }
        
        File file;
        
        if (relPath.contains("..") ||
                (relPath.length() >= 2 &&
                ((relPath.charAt(0) >= 'a' && relPath.charAt(0) <= 'z') ||
                        (relPath.charAt(0) >= 'A' && relPath.charAt(0) <= 'Z')) &&
                relPath.charAt(1) == ':' &&
                (relPath.length() <= 2 || relPath.charAt(2) == '/' || relPath.charAt(2) == '\\') )
           ) {
            // avoid path traversals, see
            // https://cwe.mitre.org/data/definitions/22.html
            throw new SecurityException("Invalid path traversal.");
        }
        
        file = new File(this.directory,relPath);
        
        InputStream inputStream = new FileInputStream(file);
        HttpResource httpResource = new InputStreamHttpResource(inputStream, bufferSize);
        return httpResource;
    }
}
