package org.clazzes.util.http;

/** This interface is motivated by the need for a bridge between the job-ids sched-util deals with, 
 *  and paths needed by the DownloadServlet.
 *  
 *  The idea is implementing the PathGetter in the particular project, injecting it into the DownloadServlet,
 *  and using the jobId parameter of the DownloadServlet.  This way, the DownloadServlet can be used in a
 *  usual way, although the client has only knowledge about a jobId, not about a path.
 */
public interface PathGetter {
    
    /** Given some sort of a key (e.g. a jobId in the sense of sched-util), return a path as needed by 
     *  e.g. the DownloadServlet.
     *  
     *  Note that the returned path must have "/" as separator character, *not* File.separator.  The transition
     *  from these paths to paths in the file system is done in the HttpResourceResolver.
     * 
     * @param key some key
     * @return a path as described
     */
    public String getPath(String key);

}
