/***********************************************************
 * $Id: SingletonUrlParameterConsumer.java 943 2014-02-18 19:07:48Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 18.02.2014
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http;

/**
 * A consumer to extract a single parameter from a query string.
 */
public class SingletonUrlParameterConsumer implements UrlParameterConsumer {

    private final String key;
    private String value;
    
    /**
     * @param key The key to extract the first value of from the
     *            parsed values. 
     */
    public SingletonUrlParameterConsumer(String key) {
        super();
        this.key = key;
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.UrlParameterConsumer#setParameter(java.lang.String, java.lang.String)
     */
    @Override
    public boolean addParameter(String k, String v) {
       
        boolean ret = this.key.equals(k);
         
        if (ret) {
            this.value = v;
        }
        
        return ret;
    }

    /**
     * @return The key to extract.
     */
    public String getKey() {
        return this.key;
    }

    /**
     * @return The first value for the given key extracted from the values
     *         passed to {@link #addParameter(String, String)}.
     */
    public String getValue() {
        return this.value;
    }

    
}
