/***********************************************************
 * $Id: HttpLoginServiceSupport.java 1110 2015-12-07 22:55:49Z util $
 * 
 * HTTP Utility classes of the clazzes.org project
 * http://www.clazzes.org
 *
 * Created: 07.12.2015
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 ***********************************************************/

package org.clazzes.util.http.sec;

import java.security.Principal;
import java.util.Locale;
import java.util.TimeZone;

import javax.servlet.http.HttpServletRequest;

/**
 * <p>A login service, which delegates to a configured delegate
 * login service.<p>
 * 
 * <p>The main purpose of this class is to use it as a base class
 * for project-specific login service which intend to override the
 * {@link #checkPermission(HttpServletRequest, String)} method.
 * </p>
 */
public class HttpLoginServiceSupport implements HttpLoginService {

    private HttpLoginService delegate;
    
    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#getLoginUrl()
     */
    @Override
    public String getLoginUrl() {
        
        if (this.delegate == null) return null;
        
        return this.delegate.getLoginUrl();
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#checkLogin(javax.servlet.http.HttpServletRequest)
     */
    @Override
    public Principal checkLogin(HttpServletRequest request) {
        
        if (this.delegate == null) return null;

        return this.delegate.checkLogin(request);
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#getLocale(javax.servlet.http.HttpServletRequest)
     */
    @Override
    public Locale getLocale(HttpServletRequest request) {
        
        if (this.delegate == null) {
            return request.getLocale();
        }

        return this.delegate.getLocale(request);
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#getTimeZone(javax.servlet.http.HttpServletRequest)
     */
    @Override
    public TimeZone getTimeZone(HttpServletRequest request) {
        
        if (this.delegate == null) {
            return TimeZone.getDefault();
        }

        return this.delegate.getTimeZone(request);
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#checkPermission(javax.servlet.http.HttpServletRequest, java.lang.String)
     */
    @Override
    public boolean checkPermission(HttpServletRequest request, String context) {
        
        if (this.delegate == null) {
            return false;
        }

        return this.delegate.checkPermission(request,context);
    }

    /* (non-Javadoc)
     * @see org.clazzes.util.http.sec.HttpLoginService#logout(javax.servlet.http.HttpServletRequest)
     */
    @Override
    public void logout(HttpServletRequest request) {
        
        if (this.delegate == null) {
            return;
        }

        this.delegate.logout(request);
    }

    /**
     * @return The login service to delegate the default implementations to.
     */
    public HttpLoginService getDelegate() {
        return this.delegate;
    }

    /**
     * @param delegate The login service to delegate the default
     *        implementations to.
     */
    public void setDelegate(HttpLoginService delegate) {
        this.delegate = delegate;
    }
    
}
